@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.19_06'; # TRIAL VERSION
+our $VERSION = '1.19_07'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -78,7 +78,6 @@ sub script_compiles {
   my $unix   = shift @$args;
   my $path   = path( $unix );
   my $pargs  = _perl_args($path);
-  my @libs   = map { "-I$_" } grep {!ref($_)} @INC;
   my $dir    = _preload_module();
   my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
   my ($stdout, $stderr) = capture { system(@$cmd) };
@@ -104,7 +103,13 @@ sub script_compiles {
 # safer as very long argument lists can break calls to system
 sub _preload_module
 {
-  my $dir = tempdir( '.test-script-XXXXX', DIR => File::Spec->curdir, CLEANUP => 1 );
+  my @opts = ( '.test-script-XXXXXXXX', CLEANUP => 1);
+  if(-w File::Spec->curdir)
+  { push @opts, DIR => File::Spec->curdir }
+  else
+  { push @opts, DIR => File::Spec->tmpdir }
+  my $dir = tempdir(@opts);
+  $dir = File::Spec->rel2abs($dir);
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
@@ -342,7 +347,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.19_06
+version 1.19_07
 
 =head1 SYNOPSIS
 
